EXPORTS
	??1CRPSMaster@@QAE@XZ @ 1 NONAME ; CRPSMaster::~CRPSMaster(void)
	?AnswerNextCallHangUpL@CRPSMaster@@QAEXW4TEtelLine@@H@Z @ 2 NONAME ; void CRPSMaster::AnswerNextCallHangUpL(enum TEtelLine, int)
	?AnswerNextCallHoldL@CRPSMaster@@QAEXW4TEtelLine@@H@Z @ 3 NONAME ; void CRPSMaster::AnswerNextCallHoldL(enum TEtelLine, int)
	?AnswerNextCallL@CRPSMaster@@QAEXW4TEtelLine@@@Z @ 4 NONAME ; void CRPSMaster::AnswerNextCallL(enum TEtelLine)
	?CallNumberHangUpAfterConnectL@CRPSMaster@@QAEXABVTDesC16@@W4TEtelLine@@H@Z @ 5 NONAME ; void CRPSMaster::CallNumberHangUpAfterConnectL(class TDesC16 const &, enum TEtelLine, int)
	?CallNumberHangUpBeforeConnectL@CRPSMaster@@QAEXABVTDesC16@@W4TEtelLine@@H@Z @ 6 NONAME ; void CRPSMaster::CallNumberHangUpBeforeConnectL(class TDesC16 const &, enum TEtelLine, int)
	?CallNumberHangUpL@CRPSMaster@@QAEXABVTDesC16@@W4TEtelLine@@H@Z @ 7 NONAME ; void CRPSMaster::CallNumberHangUpL(class TDesC16 const &, enum TEtelLine, int)
	?CallNumberL@CRPSMaster@@QAEXABVTDesC16@@W4TEtelLine@@@Z @ 8 NONAME ; void CRPSMaster::CallNumberL(class TDesC16 const &, enum TEtelLine)
	?CheckRpsPresentL@CRPSMaster@@QAEXAAH@Z @ 9 NONAME ; void CRPSMaster::CheckRpsPresentL(int &)
	?HangUpL@CRPSMaster@@QAEXW4TEtelLine@@H@Z @ 10 NONAME ; void CRPSMaster::HangUpL(enum TEtelLine, int)
	?HangUpNextCallBeforeConnectL@CRPSMaster@@QAEXW4TEtelLine@@@Z @ 11 NONAME ; void CRPSMaster::HangUpNextCallBeforeConnectL(enum TEtelLine)
	?HoldL@CRPSMaster@@QAEXW4TEtelLine@@H@Z @ 12 NONAME ; void CRPSMaster::HoldL(enum TEtelLine, int)
	?IgnoreNextCallL@CRPSMaster@@QAEXW4TEtelLine@@@Z @ 13 NONAME ; void CRPSMaster::IgnoreNextCallL(enum TEtelLine)
	?NewL@CRPSMaster@@SAPAV1@XZ @ 14 NONAME ; class CRPSMaster * CRPSMaster::NewL(void)
	?NewLC@CRPSMaster@@SAPAV1@XZ @ 15 NONAME ; class CRPSMaster * CRPSMaster::NewLC(void)
	?RejectNextCallL@CRPSMaster@@QAEXW4TEtelLine@@@Z @ 16 NONAME ; void CRPSMaster::RejectNextCallL(enum TEtelLine)
	?ResumeL@CRPSMaster@@QAEXW4TEtelLine@@H@Z @ 17 NONAME ; void CRPSMaster::ResumeL(enum TEtelLine, int)
	?RpsSlaveTelNum@CRPSMaster@@QAEABVTDesC16@@XZ @ 18 NONAME ; class TDesC16 const & CRPSMaster::RpsSlaveTelNum(void)
	?RpsSlaveTelNumData@CRPSMaster@@QAEABVTDesC16@@XZ @ 19 NONAME ; class TDesC16 const & CRPSMaster::RpsSlaveTelNumData(void)
	?RpsSlaveTelNumFax@CRPSMaster@@QAEABVTDesC16@@XZ @ 20 NONAME ; class TDesC16 const & CRPSMaster::RpsSlaveTelNumFax(void)
	?SendDataBackOnDataPortL@CRPSMaster@@QAEXABVTDesC16@@@Z @ 21 NONAME ; void CRPSMaster::SendDataBackOnDataPortL(class TDesC16 const &)
	?CleanupL@CRPSMaster@@QAEXXZ @ 22 NONAME ; void CRPSMaster::CleanupL(void)

